#
# spec file for package purpose
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5Purpose5
%define _tar_path 5.55
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           purpose
Version:        5.55.0
Release:        lp151.1.2
Summary:        Framework to integrate services and actions in applications
License:        LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  cmake >= 2.8.12
BuildRequires:  extra-cmake-modules >= 1.7.0
BuildRequires:  intltool
BuildRequires:  kaccounts-integration-devel
BuildRequires:  kconfig-devel >= %{_kf5_bugfix_version}
BuildRequires:  kcoreaddons-devel >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel >= %{_kf5_bugfix_version}
BuildRequires:  kio-devel >= %{_kf5_bugfix_version}
BuildRequires:  libaccounts-glib-devel
BuildRequires:  libaccounts-qt5-devel
BuildRequires:  libsignon-qt5-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Qml) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2.0
Requires:       kdeclarative-components >= %{_kf5_bugfix_version}
Requires:       libKF5QuickAddons5 >= %{_kf5_bugfix_version}
Requires:       libqt5-qtquickcontrols2
Recommends:     %{name}-lang
Suggests:       kdeconnect-kde

%description
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

%package -n %{lname}
Summary:        Framework to integrate services and actions - core library
Group:          System/Libraries
Recommends:     %{name}

%description -n %{lname}
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

This package contains the core library files of the package.

%package -n libKF5PurposeWidgets5
Summary:        Framework to integrate services and actions - GUI library
Group:          System/Libraries
Recommends:     %{name}

%description -n libKF5PurposeWidgets5
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

This package contains the library files of the package needed to use GUI widgets.

%package devel
Summary:        Framework to integrate services and actions - Build Environment
Group:          Development/Libraries/KDE
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules
Requires:       kcoreaddons-devel >= %{_kf5_bugfix_version}
Requires:       libKF5PurposeWidgets5 = %{version}

%description devel
This package contains development files needed to build applications which rely on the purpose framework.

%lang_package

%prep
%setup -q
%if 0%{?suse_version} == 1500
sed -i -e "s/^set *(REQUIRED_QT_VERSION 5.10.0)$/set(REQUIRED_QT_VERSION 5.9.0)/" CMakeLists.txt
%endif

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build

%if %{with lang}
  %find_lang libpurpose_quick %{name}.lang
  %find_lang libpurpose_widgets %{name}.lang
  %find_lang purpose_email %{name}.lang
  %find_lang purpose-fileitemaction %{name}.lang
  %find_lang purpose_kdeconnect %{name}.lang
  %find_lang purpose_imgur %{name}.lang
  %find_lang purpose_ktp-sendfile %{name}.lang
  %find_lang purpose_nextcloud %{name}.lang
  %find_lang purpose_pastebin %{name}.lang
  %find_lang purpose_phabricator %{name}.lang
  %find_lang purpose_reviewboard %{name}.lang
  %find_lang purpose_saveas %{name}.lang
  %find_lang purpose_twitter %{name}.lang
  %find_lang purpose_youtube %{name}.lang
%endif

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig
%post -n libKF5PurposeWidgets5 -p /sbin/ldconfig
%postun -n libKF5PurposeWidgets5 -p /sbin/ldconfig
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%if %{with lang}
%files lang -f %{name}.lang
%endif

%files -n %{lname}
%license COPYING*
%{_kf5_libdir}/libKF5Purpose.so.*
%{_kf5_debugdir}/*.categories

%files -n libKF5PurposeWidgets5
%{_kf5_libdir}/libKF5PurposeWidgets.so.*

%files
%{_kf5_libdir}/libPhabricatorHelpers.so.*
%{_kf5_libdir}/libReviewboardHelpers.so.*
%{_kf5_libexecdir}/
%{_kf5_sharedir}/purpose/
%{_kf5_sharedir}/kpackage/
%{_kf5_plugindir}/
%{_kf5_qmldir}/
%{_kf5_iconsdir}/hicolor/*/actions/kipiplugin_youtube.*
%{_kf5_iconsdir}/hicolor/*/apps/phabricator-purpose.*
%{_kf5_iconsdir}/hicolor/*/apps/reviewboard-purpose.*
%{_kf5_sharedir}/accounts/

%files devel
%{_kf5_libdir}/libKF5Purpose.so
%{_kf5_libdir}/libKF5PurposeWidgets.so
%{_kf5_libdir}/cmake/KDEExperimentalPurpose/
%{_kf5_includedir}/
%dir %{_kf5_cmakedir}/KF5Purpose
%{_kf5_cmakedir}/KF5Purpose/*.cmake

%changelog
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Use the nicer K_PLUGIN_CLASS_WITH_JSON
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * remove obsolete comment
  * add missing properties
  * Add plugin type for sharing URLs
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * DiffListModel::refresh(): return at once when already active.
  * phabricator plugin: use Arcanist's diff.rev. order (kde#401565)
  * Remove unneeded import
  * Provide a title for JobDialog
  * Allow the JobDialog to get a nicer initial size (kde#400873)
  * Make it possible for the menudemo to share different urls
  * Port what we can to QQC2
  * Use QQC2 for the JobDialog (kde#400996, kde#400997)
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Reuse resultMap instead of converting to map two times more
  * Remove unused variable
  * Set Dialog flag for JobDialog
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Add explicit
  * Make cmake 3.0 the minimum cmake version
  * phabricator: Fix warning
  * Make compile with strict compile flags
  * Port to debug categories
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * autotests: use QTemporaryDir instead of a hardcoded filename
  * autotests: remove dependency on klauncher, in the hope to fix Windows CI
  * autotests: actually disable copyjob debug output in CI
  * Use a temp dir so that an existing /tmp/purposetest file doesn't break the test.
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Make sure debugging for kf5.kio.core.copyjob is disabled for the test
  * Don't clean up the configuration too early
  * Add bluetooth plugin
  * [Telegram] Don't wait for Telegram to be closed
  * Prepare to use Arc's status colours in the revision drop-down list
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Add Share action to Dolphin context menu
  * Properly reset plugins
  * Filter out duplicate plugins
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Extend X-Purpose-Constraints documentation
  * Improve Telegram integration
  * Treat inner arrays as OR constraints rather than AND
  * Make it possible to constrain plugins by a desktop file presence
  * Make it possible to filter plugins by executable
  * Fix i18n
  * Fix i18n issues in Phabricator Plugin
  * Highlight the selected device in the KDE Connect plugin
  * Fix Phabricator icon
  * fix i18n issues in framworks/purpose/plugins
  * Use override
  * Add Telegram plugin
  * kdeconnect: Notify when the process fails to start
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Readability
  * Make sure we give some vertical space to configuration plugins
  * Port KDEConnect plugin config to QQC2
  * Port AlternativesView to QQC2
  * Warning--
- Adjust runtime requirements
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * We use qt5.8.0 now
  * Use qt5.8.0 as all framework
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * forgot to commit it
  * Generate debug categories and create file for it
  * Fix tier, accommodate for KIO
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * Now part of KDE Frameworks 5
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 1.2.1:
  * Too many changes to list here
* Fri Oct 27 2017 wbauer@tmo.at
- Update to 1.2.1
  * Add back the translations that were missing completely in 1.2
* Mon Oct 23 2017 wbauer@tmo.at
- Update to 1.2
  * New plugins: nextcloud, email, phabricator
  * Possibility to disable plugins via config file
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 1.1
  * No changelog provided
* Sat Oct  3 2015 hrvoje.senjan@gmail.com
- Update to 1.0
  * No changelog provided
- Drop build.patch, upstreamed
* Tue Aug 18 2015 hrvoje.senjan@gmail.com
- Install license
* Mon Aug 17 2015 hrvoje.senjan@gmail.com
- Don't ship reviewboard icon, it's delivered with kdevplatform
* Sun Aug  9 2015 hrvoje.senjan@gmail.com
- Activate purpose package
